//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function v = %Robot_e(field, l)
    v = [];
    if typeof(l)=="Robot" then
        select convstr(field,"l")
        case "plot" then
            if ~isempty(l.q) then
                v = l.q;
            else
                warning("Undefined joint pose.");
                v= zeros(1,l.n)
            end
        case "plot_robot" then
            if ~isempty(l.q) then
                v = l.q;
            else
                warning("Undefined joint pose.");
                v= zeros(1,l.n)
            end
        case "rp" then
            v =RP(l);
        case "teach" then
            v = teach(l);
        case "isspherical" then
            v = isspherical(l);
        //case "dyn" then
        //    dyn(l);
        case "gravity" then
            v = l.gravity;
        case "tool" then
            v = l.tool;
        case "base" then
            v = l.base;
        case "mdh" then
            v = l.mdh;
        case "offset" then
            v = [];
            for i = 1:l.n,
                v = [v; l.links(i).offset];
            end
        case "qlim" then
            v = [];
            for i = 1:l.n,
                v = [v; l.links(i).qlim];
            end
        case "dh" then
            v = [];
            for i = 1:l.n,
                v = [v; l.links(i).dh];
            end
        case "dyn" then
            l1 = l.links(1);
            v = l1.dyn;
            for i = 2:l.n,
                li = l.links(i);
                if length(li.m) ~= length(l1.m) then
                    error("cannot return the legacy DYN matrix: masses have incompatible dimensions");
                elseif length(li.r) ~= length(l1.r) then
                    error("cannot return the legacy DYN matrix: COG vectors have incompatible dimensions");
                elseif length(li.I) ~= length(l1.I) then
                    error("cannot return the legacy DYN matrix: inertia matrices have incompatible dimensions");
                elseif length(li.Jm) ~= length(l1.Jm) then
                    error("cannot return the legacy DYN matrix: motor inertias have incompatible dimensions");
                elseif length(li.G) ~= length(l1.G) then
                    error("cannot return the legacy DYN matrix: gear ratios have incompatible dimensions");
                else
                    v = [v; li.dyn];
                end
            end
        case "islimit" then
            error("Use ''islimit(robot,q)''");
        case "fkine" then
            error("Use ''fkine(robot,q)''");
        case "ikine6s" then
            error("Use ''ikine6s(robot,T)''");
        case "ikine3" then
            error("Use ''ikine3(robot,T)''");
        case "ikine" then
            error("Use ''ikine(robot,T)''");
        case "jacob0" then
            error("Use ''jacob0(robot,Q)''");
        case "jacobn" then
            error("Use ''jacobn(robot,Q)''");
        case "maniplty" then
            error("Use ''maniplty(robot,Q)''");
        case "accel" then
            error("Use ''accel(robot, Q, QD, TORQUE)''");
        case "coriolis" then
            error("Use ''coriolis(robot, Q, QD)''");
        case "fdyn" then
            error("Use ''fdyn(robot, T, TORQFUN)''");
        case "friction" then
            error("Use ''friction(robot, QD)''");
        case "gravload" then
            error("Use ''gravload(robot, Q)''");
        case "inertia" then
            error("Use ''inertia(robot, Q)''");
        case "nofriction" then
            v = nofriction(l);
            warning("Options will not considered, use ''nofriction(robot,options)''");
        case "rne" then
            error("Use ''rne(robot, Q, QD, QDD)''");
        case "payload" then
            error("Use ''payload(robot, M, P)''");
        case "perturb" then
            v = perturb(l);
            warning("Options will not considered, default P=10%. Use ''perturb(robot,P)''");
        else
            error('Invalid field');
            v=[];
        end
    end
endfunction
