//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function v = RP(l)
    // Joint type
    //
	// Calling Sequence   
	//  c = RP(L)
	//	c = RP(ROBOT)
	//
	// Parameters
	// L    : Link object
	// ROBOT : SerialLink object
	//
	// Description
    // c = RP(L) is a character 'R' or 'P' depending on whether joint is revolute or prismatic respectively.
    //
	// c = RP(ROBOT)
    // If L is a vector of Link or a SerialLink objects return a string of characters
	// in joint order.
	//
	// See also
	//	Link
	//	SerialLink
	//
	// Authors
	// Copyright (C) 1993-2011 - Peter I. Corke
	// Copyright (C) 2014-20 - Davide Cappucci

    v="";
    if(typeof(l)=="Link")
        if l.sigma == 0
            v = 'R';
        else
            v = 'P';
        end
    elseif (typeof(l)=="list" | typeof(l)=="Robot")  then
        if(typeof(l)=="Robot") then
            l=l.links;
        end

        for i=1:size(l),
            if l(i).sigma == 0
                v = strcat([v,"R"]);
            else
                v = strcat([v,"P"]);
            end
        end
    end

endfunction
