//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function tg = gravload(robot, q, grav)
    //Gravity loading
    //
    // Calling Sequence
    // TAUG = gravload(ROBOT,Q)
    // TAUG = gravload(ROBOT,Q, GRAV)
    //
    // Description
    // <literal>TAUG = gravload(ROBOT,Q)</literal> is the joint gravity loading for the robot in the
    // joint configuration Q.  Gravitational acceleration is a property of the
    // robot object.
    //
    // If Q is a row vector, the result is a row vector of joint torques.  If 
    // Q is a matrix, each row is interpreted as a joint configuration vector, 
    // and the result is a matrix each row being the corresponding joint torques.
    //
    // <literal>TAUG = gravload(ROBOT,Q, GRAV)</literal> is as above but the gravitational 
    // acceleration vector GRAV is given explicitly.
    //
    // See also 
    // SerialLink
    // rne
    // itorque
    // coriolis
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci

    [%nargout,%nargin]=argn(0);

    if numcols(q) ~= robot.n
        error('Insufficient columns in q')
    end
    if %nargin == 2
        tg = rne(robot, q, zeros(size(q,1),size(q,2)), zeros(size(q,1),size(q,2)));
    elseif %nargin == 3
        tg = rne(robot, q, zeros(size(q,1),size(q,2)), zeros(size(q,1),size(q,2)), grav);
    end
endfunction
