//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function v = islimit(l,q)
    // Test joint limits
    // 
    // Calling Sequence
    // V = islimit(L,Q)
    // V = islimit(ROBOT,Q)
    //
    //  Description
    // <literal>V = islimit(L,Q)</literal> is true (1) if Q is outside 
    // the soft limits set for this joint.
    //
    // <literal>V = islimit(ROBOT,Q)</literal> is a vector of boolean values, 
    // one per joint, false (0) if Q(i) is within the joint limits, else true (1).
    //
    // Joint limits are purely advisory and are not used in any other function. 
    // Just seemed like a useful thing to include...
    //
    // See also 
    //	Link
    //
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci
    
    if typeof(l)=="Link"  then
        if isempty(mtlb_e(l,"qlim")) then
            error("no limits assigned to link")
        end;
        v = mtlb_s(bool2s(mtlb_logic(mtlb_double(q),">",mtlb_double(l.qlim(2)))),mtlb_logic(mtlb_double(q),"<",mtlb_double(l.qlim(1))));
    end

    if typeof(l)=="Robot"  then
        L = l.links;
        if length(q) ~= l.n
            error('argument for islimit method is wrong length');
        end
        v = zeros(l.n, 2);
        for i=1:l.n
            v(i,:) = islimit(L(i),q(i));
        end
    end
endfunction
