//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function [x, y, typ] = jtraj_if(job, arg1, arg2)
    style = 'blockWithLabel;fillColor=red;displayedLabel=jtraj;fontStyle=1;fontSize=12;align=left';
    x = [];
    y = [];
    typ = [];
    select job,
        case "set" then
            x = arg1;
            graphics = arg1.graphics;
            exprs = graphics.exprs;
            model = arg1.model;
            while %T do,
                [ok, q0, qf, tmax, exprs] = scicos_getvalue(..
                    ["Joint interpolated trajectory"],..
                    ["q0";..
                    "qf";..
                    "tmax"],..
                    list("vec", -1,"vec", -1,"vec", 1),..
                    exprs);
                if length(q0) ~= length(qf) then
                    message("q0 and qf must be same length");
                    ok = %F;
                elseif (length(q0) ~= 0) &..
                        ((size(q0,1) ~= 1 & size(q0,2) ~= 1) | (size(qf,1) ~= 1 & size(qf,2) ~= 1)) then
                    message("q0 and qf must be vectors");
                    ok = %F;
                end
                if ~ok then
                    break;
                end
                n = length(q0);
                [model, graphics, ok] = set_io(model, graphics, list(), list([n, 1; n, 1; n, 1], [1; 1; 1]), [], []);
                if ok then
                    t = [0:100].' / 100 * tmax;
                    [q, qd, qdd] = jtraj(q0, qf, t);
                    graphics.exprs = exprs;
                    model.rpar = [q, qd, qdd, t];
                    model.ipar=n;
                    graphics.out_label = ['q';'qd';'qdd'];
                    graphics.style =  style;
                    x.graphics=graphics;
                    x.model=model;
                    break;
                end
            end

        case "define" then
            q0 = [0, 0, 0, 0, 0, 0];
            qf = [%pi/4, %pi/2, -%pi/2, 0, 0, 0];
            tmax = 10;
            t = [0:100].' / 100 * tmax;

            // at build time jtraj is unknown to scilab, so that it must be loaded before its first call
            try
              exec(get_absolute_file_path("buildmacros.sce")+"jtraj.sci");
            end
          
            [q, qd, qdd] = jtraj(q0, qf, t);
            model = scicos_model();
            model.sim = list("jtraj_cf",5);
            model.in = [];
            model.in2 = [];
            model.intyp = [];
            model.out = [6; 6; 6];
            model.out2 = [1; 1; 1];
            model.outtyp = [1; 1; 1];
            model.evtin = [];
            model.evtout = [];
            model.rpar = [q, qd, qdd, t];
            model.ipar = 6;
            model.blocktype = "d";
            model.dep_ut = [%T %T];
            exprs = [sci2exp(q0); sci2exp(qf); sci2exp(tmax)];
            x = standard_define([4 4], model, exprs, "");
            x.graphics.out_label = ['q';'qd';'qdd'];
            x.graphics.style = style;
    end

endfunction
