//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function mdl_MotomanHP6()
    // Create kinematic data of a Motoman HP6 manipulator
    // 
    // Calling Sequence
    // mdl_motomanHP6
    //
    // Description
    // Script creates the workspace variable R which describes the 
    // kinematic characteristics of a Motoman HP6 manipulator
    // using standard DH conventions.
    //
    // Also defines the workspace vector:
    //
    //   q0    mastering position.
    //
    // Author: Wynand Swart, Mega Robots CC, P/O Box 8412, Pretoria, 0001, South Africa
    //
    // See also 
    // SerialLink
    // mdl_puma560akb
    // mdl_stanford
    // mdl_twolink.
    //
    // Authors
    //  Wynand Swart, Mega Robots CC, P/O Box 8412, Pretoria, 0001, South Africa, wynand.swart@gmail.com
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci

    //Cell: 073-1555-430
    //30 Sep 2007
    //Motoman HP robot

    //##########################################################
    L = list();
    //            theta    d      a      alpha
    L(1) = Link([ 0       0      0.15   -%pi/2   0]);
    L(2) = Link([ 0       0      0.57   -%pi     0]);
    L(3) = Link([ 0       0      0.155  -%pi/2   0]);
    L(4) = Link([ 0      -0.635  0       %pi/2   0]);
    L(5) = Link([ 0       0      0      -%pi/2   0]);
    L(6) = Link([ 0      -0.095  0       %pi     0]);
    //##########################################################
    //Pose 0; At ZERO position
    //##########################################################
    q0 =[0   -%pi/2   0   0   -%pi/2   0];
    R=SerialLink(L, 'name', 'Motoman HP6');
    //##########################################################
    [R,q0]=resume(R,q0);
endfunction
