//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function r = qrot(q)
    // Convert toorthonormal rotation matrix
    //
    // Description
    // <literal>R = qrot(Q)</literal> is the equivalent 3x3 orthonormal rotation matrix.
    //
    // <refsection>
	// <title>Notes</title>
	// <itemizedlist>
    // <listitem><para>For a quaternion sequence returns a rotation matrix sequence.</para></listitem>
    // </itemizedlist>
	// </refsection>
    //
    // See also 
    // Quaternion
    // 
    // Authors
    // Copyright (C) 1993-2011 - Peter I. Corke
    // Copyright (C) 2014-20 - Davide Cappucci

    if  typeof(q)=="list" then
        r = zeros(3,3,length(q));
        for i=1:length(q)
            r(:,:,i) = t2r( q2tr(q(i)) );
        end
    else
        r =t2r( q2tr(q) );
    end
endfunction
