//  Copyright (C) 2014-20 - Davide Cappucci
//
//  This file is part of Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.

function I = set_I(v)
// Set link inertia
//
// Description
// <literal>L.I = [Ixx Iyy Izz]</literal> set link inertia to a diagonal matrix.
//
// <literal>L.I = [Ixx Iyy Izz Ixy Iyz Ixz]</literal> set link inertia to a symmetric matrix with
// specified inertia and product of intertia elements.
//
// <literal>L.I = M</literal> set Link inertia matrix to M (3x3) which must be symmetric.
//
// Bibliography
// [1] Robotics, Vision & Control, Chap 7, P. Corke, Springer 2011. 
//
// See also
//	Link
//
// Authors
// Copyright (C) 1993-2011 - Peter I. Corke
// Copyright (C) 2014-20 - Davide Cappucci

    if isempty(v)
        return;
    end
    if and(size(v) == [3 3]) then
        if typeof(v)== 'double' & norm(v-v') > %eps then
            error('inertia matrix must be symmetric');
        end
        I = v;
    elseif length(v) == 3
        I = diag(v);
    elseif length(v) == 6
        I = [ v(1) v(4) v(6)
        v(4) v(2) v(5)
        v(6) v(5) v(3) ];
    else
        error('must set I to 3-vector, 6-vector or symmetric 3x3');
    end
endfunction
