 #include "robot.h"
 #include "vmath.h"
 #include "sciprint.h"
 /*
#define DEBUG
*/

/* Some useful things */
#define NUMROWS(x)  mxGetM(x)
#define NUMCOLS(x)  mxGetN(x)
#define NUMELS(x)   (mxGetN(x)*mxGetM(x))
#define POINTER(x)  mxGetPr(x)

Link *cre_def_p_link()
{
    //struct link L[16];
    Link *L ;
    L = (Link *) malloc(sizeof(Link));

    L->alpha = 0;
    L->A = 0;
    L->theta = 0;
    L->D = 0;
    L->sigma = 0;
    L->mdh = 0;
    L->offset = 0;

    L->m = 0;    // m
    L->rbar = NULL;    // r
    L->I = NULL;    // I
    L->Jm = 0;   // Jm
    L->G = 0;    // G
    L->B = 0;
    L->Tc[0] = 0;   L->Tc[1] = 0;
    
    return L;
}

Link *create_link(double *dh)
{
    Link *L ;
    int i=0;
    L = (Link *) malloc(sizeof(Link));

    L->alpha = dh[1];
    L->A = dh[0];
    L->D = dh[2];
    L->theta = dh[3];
    L->sigma = (int)dh[4];
    L->mdh = (int)dh[5];
    L->offset = dh[6];
    
    L->m = dh[7];
    L->rbar = (Vect *) malloc(sizeof(Vect));
    L->rbar->x = dh[8];
    L->rbar->y = dh[9];
    L->rbar->z = dh[10];   
    L->I = (double *) malloc(9 * sizeof(double)); 
    for (i=0;i<9;++i)
        {
        L->I[i]= dh[11+i];
        }
    L->Jm = dh[20];
    L->G = dh[21];
    L->B = dh[22];
    
    L->Tc = (double *) malloc(2 * sizeof(double)); 
    L->Tc[0] = dh[23];
    L->Tc[1] = dh[24];
//    L->qlim = dh[14];
    return L;
}

Link create_link_2(double *dh)
{
    Link L ;
    int i=0;

    L.alpha = dh[1];
    L.A = dh[0];
    L.D = dh[2];
    L.theta = dh[3];
    L.sigma = (int)dh[4];
    L.mdh = (int)dh[5];
    L.offset = dh[6];
    
    L.m = dh[7];
    L.rbar = (Vect *) malloc(sizeof(Vect));
    L.rbar->x = dh[8];
    L.rbar->y = dh[9];
    L.rbar->z = dh[10];   
    L.I = (double *) malloc(9 * sizeof(double)); 
    for (i=0;i<9;++i)
        {
        L.I[i]= dh[11+i];
        }
    L.Jm = dh[20];
    L.G = dh[21];
    L.B = dh[22];
    
    L.Tc = (double *) malloc(2 * sizeof(double)); 
    L.Tc[0] = dh[23];
    L.Tc[1] = dh[24];
//    L.qlim = dh[14];
    return L;
}


void print_Link(Link *L)
{    
    sciprint("alpha=%.3f\ta = %.3f\td = %.3f\ttheta = %.3f \n",L->alpha,L->A,L->D,L->theta);

}
void print_full_Link(Link *L) 
{
    print_Link(L);
    sciprint("\n  m = %.3f\n",L->m);
    sciprint("  r = [ %.3f, %.3f, %.3f ]\n",L->rbar->x,L->rbar->y,L->rbar->z);
    sciprint("  I = | %f %f %f |\n      | %f %f %f |\n      | %f %f %f |\n",L->I[0],L->I[1],L->I[2],L->I[3],L->I[4],L->I[5],L->I[6],L->I[7],L->I[8]);
	sciprint("  Jm = %f\n",L->Jm);
	sciprint("  Bm = %f\n",L->B);
	sciprint("  Tc = %f(+) %f(-)\n",L->Tc[0],L->Tc[1]);
	sciprint("  G = %f\n",L->G);
}

Robot create_robot(Link *L,int n,double *gravity,int mdh)
{
    int j;
    Robot robot;// = (Robot *)malloc(sizeof(Robot));
    
    robot.gravity = (Vect *) malloc(sizeof(Vect));
    robot.gravity->x = gravity[0];
    robot.gravity->y = gravity[1];
    robot.gravity->z = gravity[2];
    
    robot.njoints = n;
    
    robot.dhtype = mdh;
    
    robot.links = (Link *) malloc(n*sizeof(Link));
    
    for (j=0; j<robot.njoints; j++) 
        {
        robot.links[j] = L[j];
    }
    return robot;
}

void print_robot(Robot robot)
{
     int j;
     sciprint("\n\n-------------------Print Robot:--------------------------");
     sciprint("\nGravity = [ %.2f %.2f %.2f ]\n",robot.gravity->x,robot.gravity->y,robot.gravity->z);
     sciprint("\nDH Type = %d \n\n",robot.dhtype);
     for (j=0; j<robot.njoints; j++) 
        {
        sciprint("L%d:  ",j);
        print_Link(&robot.links[j]);
        //equivalente a:
        //sciprint("L%d:  alpha=%.3f\ta = %.3f\td = %.3f\ttheta = %.3f\n",j+1,robot.links[j].alpha,robot.links[j].A,robot.links[j].D,robot.links[j].theta);
    }
}

void free_link(Link *L){
    free(L->rbar);
    free(L->I);
    free(L->Tc);
    free(L);
}

void free_robot(Robot robot)
{
    free(robot.gravity);
    free_link(robot.links);
}


void rot_mat(Link *l, double th, double d, DHType type)
{
    double      st, ct, sa, ca;

#ifdef  sun
    sincos(th, &st, &ct);
    sincos(l->alpha, &sa, &ca);
#else
    st = sin(th);
    ct = cos(th);
    sa = sin(l->alpha);
    ca = cos(l->alpha);
#endif

    switch (type) {
case STANDARD:
    l->R.n.x = ct;      l->R.o.x = -ca*st;  l->R.a.x = sa*st;
    l->R.n.y = st;      l->R.o.y = ca*ct;   l->R.a.y = -sa*ct;
    l->R.n.z = 0.0;     l->R.o.z = sa;      l->R.a.z = ca;

    l->r.x = l->A;
    l->r.y = d * sa;
    l->r.z = d * ca;
    break;
case MODIFIED:
    l->R.n.x = ct;      l->R.o.x = -st;     l->R.a.x = 0.0;
    l->R.n.y = st*ca;   l->R.o.y = ca*ct;   l->R.a.y = -sa;
    l->R.n.z = st*sa;   l->R.o.z = ct*sa;   l->R.a.z = ca;

    l->r.x = l->A;
    l->r.y = -d * sa;
    l->r.z = d * ca;
    break;
    }
}
