/*  Copyright (C) 2020 - Corrado Guarino Lo Bianco
*
*  This file is part of the Robotics Toolbox for Scilab.
*
*  Robotics Toolbox is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  Robotics Toolbox is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
*  by Peter Corke.
*/

#include <math.h> /* atan2 */
#include <float.h> /* DBL_EPSILON */

int t2eul(double *t, double *alpha, double *beta, double *gamma)
{

	double sa, ca;
	
    if (fabs(t[10]) < DBL_EPSILON & fabs(t[9]) < DBL_EPSILON)
    {
        // singularity
        *alpha = 0.0;  // alpha is zero
        *beta = atan2(t[8], 0.0);  // beta
        *gamma = atan2(t[1], t[5]);  // gamma is sum of alpha+gamma
    }
    else
    {
        *alpha = atan2(-t[9], t[10]);        // alpha
        // compute sin/cos of alpha angle
        sa = sin(*alpha);	ca = cos(*alpha);
        *beta = atan2(t[8], ca * t[10] - sa * t[9]);  // beta
        *gamma = atan2(-t[4], t[0]);        // gamma
    } 
      
    return 0;
}
