//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.
//
// TEST QUATERNION CALLING SEQUENCE //
// 
// Function checked:
// Quaternion.sci
// %Quat_o_Quat
// %Quat_o_l
// %l_o_Quat
// 
// 
//Calling Sequence
//Q0 = Quaternion()
//Q1 = Quaternion(Q0)
//Q2 = Quaternion([S V1 V2 V3])
//Q3 = Quaternion(S)
//Q4 = Quaternion(TH, V)
//Q5 = Quaternion(R)
//Q6 = Quaternion(T)

//Create Quaternions
quat0 = Quaternion();
quat1 = Quaternion(quat0);
quat2 = Quaternion([sqrt(2)/2, sqrt(2)/2, 0, 0]);
quat3 = Quaternion(1); 
quat4 = Quaternion(%pi/2, [1,0,0]);
quat5 = Quaternion(rotx(%pi/2));
T = r2t(rotx(%pi/2));
quat6 = Quaternion(T);

// the result should be:
//quat0 == quat1 == quat3
//quat2 == quat4 == quat5 == quat6

assert_checkequal( quat0.s , 1);
assert_checkequal( quat0.v , [0, 0, 0]);
assert_checkequal( quat0.s , quat1.s);
assert_checkequal( quat0.v , quat1.v);
assert_checkequal( quat0.s , quat3.s);
assert_checkequal( quat0.v , quat3.v);

assert_checkalmostequal(quat2.s, quat4.s ,1.e-15);
assert_checkalmostequal(quat2.v, quat4.v ,1.e-15);

assert_checkequal( quat4.s , quat5.s);
assert_checkequal( quat4.v , quat5.v);

assert_checkequal( quat4.s , quat6.s);
assert_checkequal( quat4.v , quat6.v);


//CHECK %Quat_o_Quat
assert_checktrue([quat0 == quat1, quat0 == quat3])
//assert_checktrue(quat2 == quat4)
assert_checktrue(quat4 == quat5)
assert_checktrue(quat4 == quat6)

//CHECK %l_o_Quat
L1 =list(quat0, quat1, quat3)
L2 =list(quat2, quat4, quat5, quat6)
assert_checktrue(L1 == quat1)
//assert_checktrue(L2 == quat2)

//CHECK %Quat_o_l
assert_checktrue(quat1 == L1);
//assert_checktrue(quat2 == L2);

clear quat0 quat1 quat2 quat3 quat4 quat5 quat6 T L1 L2
