//  Copyright (C) 2014 - Davide Cappucci
//
//  This file is part of the Robotics Toolbox for Scilab.
//
//  Robotics Toolbox is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  Robotics Toolbox is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//  This toolbox is inspired to the Robotics Toolbox v9 for MATLAB 
//  by Peter Corke.
//
// TEST SERIALLINK CALLING SEQUENCE //
//
//  1)  R = SerialLink(LINKS,OPTIONS)
//  2)  R = SerialLink(R1,OPTIONS)   
//  3)  R = SerialLink(list(R1,R2,...), OPTIONS)
//  4)  R = SerialLink(list(R1,L1,L2),OPTIONS)
//
//
// Function checked:
// SerialLink
// %Robot_m_Robot
// %Robot_m_Link
// mtimes
// and part of "%Robot_e" and "%s_i_Robot"



    L = list();
    //   theta d a alpha 
    L(1) = Link( 0  ,  0 ,  1 , 0, 'standard');
    L(2) = Link( 0  ,  0 ,  1 , 0, 'standard');

    L(1).m = 1;
    L(1).r = [-0.5 0 0];
    L(1).I = zeros(3,3);
    L(1).G = 0;
    L(1).Jm = 0;
    L(1).B = 0;
    L(2).m = 1;
    L(2).r = [-0.5 0 0];
    L(2).I = zeros(3,3);
    L(2).G = 0;
    L(2).Jm = 0;
    L(2).B = 0;
    
//--------------------------------------------------------------------------//
// 1.1)  R = SerialLink(LINKS)
// 1.2)  R = SerialLink(LINKS,OPTIONS)
//--------------------------------------------------------------------------//
    twolink = SerialLink(L);
    
    // PRIVATE PROPRIETIES //
    //READ
    assert_checktrue(length(twolink.links) == 2);
    assert_checktrue(length(twolink.links) == twolink.n);
    assert_checktrue(twolink.config == "RR");
    assert_checktrue(twolink.mdh == 0);
    //WRITE
//    assert_checkerror("twolink.n = 3", "SerialLink: ''n'' is a read only variable.");
//    assert_checkerror("twolink.mdh = 1", "SerialLink: ''mdh'' is a read only variable.");
//    assert_checkerror("twolink.config = ''RR''", "SerialLink: ''config'' is a read only variable.");

    twolink = SerialLink(L, "name", "two link", "comment", "from Spong, Hutchinson, Vidyasagar", "manuf", "i dont know");
        
    assert_checktrue(twolink.name == "two link");
    assert_checktrue(twolink.comment == "from Spong, Hutchinson, Vidyasagar");
    assert_checktrue(twolink.manuf == "i dont know");
    assert_checkequal(twolink.gravity,[0;0;9.81]);
    assert_checkequal(twolink.base, eye(4,4));
    assert_checkequal(twolink.tool, eye(4,4));
    assert_checktrue(twolink.lineopt(1) == "black");
    assert_checktrue(twolink.lineopt(2) == 7);
    assert_checktrue(twolink.shadowopt(1) == "grey70");
    assert_checktrue(twolink.shadowopt(2) == 3);

    twolink = SerialLink(L, "name", "twolink",..
                         "gravity", [0;0;0],..
                         "base", ones(4,4),..
                         "tool", zeros(4,4),..
                         "lineopt", list("grey70",10),..
                         "shadowopt", list("black",5) );
    assert_checktrue(twolink.name == "twolink");
    assert_checkequal(twolink.gravity,[0;0;0]);
    assert_checkequal(twolink.base, ones(4,4));
    assert_checkequal(twolink.tool, zeros(4,4));
    assert_checktrue(twolink.lineopt(1) == "grey70");
    assert_checktrue(twolink.lineopt(2) == 10);
    assert_checktrue(twolink.shadowopt(1) == "black");
    assert_checktrue(twolink.shadowopt(2) == 5);
        
        
//--------------------------------------------------------------------------//
// 2.1)  R = SerialLink(R1)
// 2.2)  R = SerialLink(R1,OPTIONS)   
//--------------------------------------------------------------------------//

robotclone = SerialLink(twolink);
if assert_checkequal(length(robotclone),length(twolink)) then
    for i=1:length(twolink)
        assert_checktrue(twolink(i)== robotclone(i));
    end
end
assert_checktrue(robotclone == twolink);


robotclone = SerialLink(twolink,'name','copia');
if assert_checkequal(length(robotclone),length(twolink)) then
    assert_checkfalse(twolink.name == robotclone.name);
    for i=3:length(twolink)
        assert_checktrue(twolink(i)== robotclone(i));
    end
end


//--------------------------------------------------------------------------//
// 3)  R = SerialLink(list(R1,R2,...), OPTIONS)   
// 3.1) R = R1 * R2
// 3.2) R = SerialLink(R1*R2)
// 3.3) R = SerialLink(list(R1,R2))
//--------------------------------------------------------------------------//

// 3.1) R = R1 * R2
concatRobot = twolink * twolink;
if assert_checkequal(length(concatRobot),length(twolink)) then
    for i=1:length(twolink.links)/2 //check links
        assert_checktrue(twolink.links(i)== concatRobot.links(i));
    end
    for i=length(twolink.links)/2:length(twolink.links) //check links
        assert_checktrue(twolink.links(i-length(twolink.links)+2)== concatRobot.links(i));
    end
end

// 3.2) R = SerialLink(R1*R2)
concatRobot2 = SerialLink(twolink*twolink);
assert_checktrue(concatRobot2 == concatRobot);


// 3.3) R = SerialLink(list(R1,R2)) 
concatRobot3 = SerialLink(list(twolink,twolink));
assert_checktrue(concatRobot3 == concatRobot);



//--------------------------------------------------------------------------//
// 4)  R = SerialLink(list(R1,L1,...), OPTIONS)   
// 4.1) R = R1 * L1
// 4.2) R = SerialLink(R1*L1*L2)
// 4.3) R = SerialLink(list(R1,L1,L2))
//--------------------------------------------------------------------------//
l1 = twolink.links(1);
l2 = twolink.links(2);

concatRobot4 = twolink * l1 * l2
if assert_checkequal(length(concatRobot4),length(twolink)) then
    for i=1:length(twolink.links)/2 //check links
        assert_checktrue(twolink.links(i)== concatRobot4.links(i));
    end
    for i=length(twolink.links)/2:length(twolink.links) //check links
        assert_checktrue(twolink.links(i-length(twolink.links)+2)== concatRobot4.links(i));
    end
end

concatRobot5 = SerialLink(list(twolink,l1,l2));
if assert_checkequal(length(concatRobot5),length(twolink)) then
    for i=1:length(twolink.links)/2 //check links
        assert_checktrue(twolink.links(i)== concatRobot5.links(i));
    end
    for i=length(twolink.links)/2:length(twolink.links) //check links
        assert_checktrue(twolink.links(i-length(twolink.links)+2)== concatRobot5.links(i));
    end
end


concatRobot6 = SerialLink(twolink * l1 * l2);if assert_checkequal(length(concatRobot6),length(twolink)) then
    for i=1:length(twolink.links)/2 //check links
        assert_checktrue(twolink.links(i)== concatRobot6.links(i));
    end
    for i=length(twolink.links)/2:length(twolink.links) //check links
        assert_checktrue(twolink.links(i-length(twolink.links)+2)== concatRobot6.links(i));
    end
end
clear twolink robotclone L i concatRobot concatRobot2 concatRobot3 concatRobot4 concatRobot5 concatRobot6 l1 l2
